/*************************************************************************
  (c) Copyright.  Digital Equipment Corporation, 1995.  All Rights
  Reserved.

  Permission is hereby granted to use, copy, modify, or enhance this 
  software freely, as long as the foregoing copyright of Digital Equipment
  Corporation and this notice are retained on the software.  This 
  software may not be distributed or sublicensed for a fee.  Digital      
  makes this software available "AS IS" and without warranties of any
  kind.  
 *************************************************************************/

/*
* Module Name:
*   svc.h
*
* Overview:
*   This module describes the functions exported by the svc module
*   to support the driver.
*
* Authors:
*   JAD - John A. DeNisco
*
* Modification History:
*   Date       Name  Description
*   02-Feb-95  JAD   Created
*
* Description:
*   The functions is this file describe calls made by the driver to the
*   svc module. The fuctions are used to initialize and remove the svc
*   module.
*/

/*++
* ==============
* = svc_create =
* ==============
*
* Overview:
*  This function creates an instance of the signaling module. Its primary
*  functions are to create and initialize an svc handle, initialize the SAP to
*  the connection manager, initialize the signaling wrapper, and return the svc
*  handle to the caller.
*
* Arguments:
*  gbl_os_handle  - (IN) The global OS handle to be used by this instance. This
*                        handle is used for resources that are not associated
*                        with any adapter.
*
*  adap_os_handle - (IN) The adapter OS handle to be used by this instance. This
*                        handle is used for resources allocated for a single
*                        adapter.
*
*  cm_handle      - (IN) The connection manager handle to be used by this
*                        instance.
*
*  p_text         - (IN) A constant text string to describe this instance.
*
*  p_svc_handle   - (OUT) The handle that describes the new instance.
*
* Returns:
*  STATUS_K_SUCCESS - Success, see postconditions.
*  status           - Passed back from sig_create, cm_sap_register.
*
* Preconditions:
*  None
*
* Postconditions:
*  The signal handle is valid.
--*/
STATUS svc_create (HANDLE  gbl_os_handle,
                   HANDLE  adap_os_handle,
                   HANDLE  cm_handle,
                   char   *p_text,
                   HANDLE *p_svc_handle);

/*++
* ===============
* = svc_destroy =
* ===============
*
* Overview:
*  This function destroys a previously created svc module instance. It's
*  primary functions are to free the signal resouces and release the SAP to
*  the connection manager.
*
* Arguments:
*  svc_handle - (IN) The handle returned by svc_create.
*
* Returns:
*  STATUS_K_SUCCESS - Success, see postconditions.
*
* Preconditions:
*  None
*
* Postconditions:
*  The signal handle is invalid.
--*/

void svc_destroy (HANDLE svc_handle);

/*++
* ======================
* = sig_event_mask_set =
* ======================
*
* Overview:
*   Sets the event mask which defines which classes of events are to be
*   reported.
*
* Arguments:
*   svc_handle - (IN) The handle returned by svc_create.
*   event_mask - (IN) The new value of the event mask.
*
* Returns:
*   none
*
* Preconditions:
*   none
*
* Postconditions:
*   none
*
* Issues:
*   none
--*/                                              

void svc_event_mask_set (HANDLE svc_handle,
                         UINT32 event_mask); 

