/*************************************************************************
  (c) Copyright.  Digital Equipment Corporation, 1995.  All Rights
  Reserved.

  Permission is hereby granted to use, copy, modify, or enhance this 
  software freely, as long as the foregoing copyright of Digital Equipment
  Corporation and this notice are retained on the software.  This 
  software may not be distributed or sublicensed for a fee.  Digital      
  makes this software available "AS IS" and without warranties of any
  kind.  
 *************************************************************************/

/*
* Module Name:
*   svc_info.h
*   
* Abstract:
*  This header file describes the information elements needed to support the
*  svc to connection manager interface.
*
* Authors:
*  JAD - John A. DeNisco
*
* Modification History:
*  Date       Name  Description 
*  26-Jan-95  JAD   Created.
*  21-Feb-95  JAD   Use trillium definitions directly.
*
* Description:
*  Generally the svc_info structures are used, to pass information to and
*  from the connection manager and the svc interface. The svc interface is
*  found in the modules svc_cm.h and cm_svc.h.
*
*/

/* General constants */

#define SVC_SIZE_STRING_MED              32    /* token string size - medium */
#define SVC_ELEMENT_REPEAT_MAX            2    /* maximum repeated elements  */
#define REL_LOC_USER                      0    /* ref: 5.4.5.15 UNI 3.0      */

/* Cause Values */

#define CAUSE_RESOURCE_UNAVAIL           47
#define CAUSE_NORMAL                     31

/* Event Values */

#define EVENT_CALL_PROCEEDING             0
#define EVENT_CONN_ACK                    2
#define EVENT_UNKNOWN                     9

/* The following definitions describe error conditions in the CM that result */
/* in connection releases.  These values are used as input to                */
/* "svc_release_info_make". These values can not conflict with the cause     */
/* values in the UNI specification 5.4.5.15.                                 */

#define RECORD_NOT_FOUND_ON_STATUS_IND    (0x01 | 0x8000)
#define CONN_ID_MISSING                   (0x02 | 0x8000)
#define RECORD_NOT_FOUND_ON_CONN_CFM      (0x03 | 0x8000)
#define RECORD_NOT_FOUND_ON_REL_IND       (0x04 | 0x8000)
#define REJECT_SAP_MISMATCH               (0x05 | 0x8000)
#define CAUSE_QOS_CHECK_FAIL              (0x06 | 0x8000)
#define CONN_RSP_CALL_FAILED              (0x07 | 0x8000)

/* Macros */

/* Extract the endpoint reference from a drop party info block. */

#define ENDPOINT_REF_GET(p_drop_pty_info) 

/* Extract a cause value from a release info block. */

#define CAUSE_GET(p_rel_info) 

/* Type definitions */

typedef U8    EVENT_TYPE;
typedef INT32 CALL_ID;
typedef INT16 RST_REASON;
typedef INT32 PORT_NUMBER;

/* Redefine some trilllium definitions the svc module needs */

/*++
* CONN_INFO
*
* This structure contains all of the information needed to setup a a virtual
* connection.
*
--*/



/*++
* CONN_STATUS
*
* This structure contains status related to a virtual connection.
*
--*/



/*++
* RELEASE_INFO
*
*  Information used to release a virtual connection.
*
--*/



/*++
* ADD_PTY_INFO
*
*  Information used to add a party to a virtual connection.
*
--*/




/*++
* ADD_PTY_STATUS
*
*  Status used to add a party to a virtual connection.
*
--*/



/*++
* DROP_PTY_INFO
*
*  Information used for a drop party from a virtual connection.
*
--*/




/*++
* =====================
* = svcinit_conn_info =
* =====================
*
* Overview:
*  This function initilizes the connection information structure.
*  Initilization simply involves setting all the present flags to 
*  "not present".
*
* Arguments:
*
*  p_svc_conn_info - Pointer to the connection information.
*
* Returns:
*
* None
*
--*/

void svcinit_conn_info (CONN_INFO *p_svc_conn_info);

/*++
* =======================
* = svcinit_conn_status =
* =======================
*
* Overview:
*  This function initilizes the connection status structure.
*  Initilization simply involves setting all the present flags to 
*  "not present".
*
* Arguments:
*
*  p_svc_conn_status - Pointer to the connection status.
*
* Returns:
*
* None
*
--*/

void svcinit_conn_status (CONN_STATUS *p_svc_conn_status);

/*++
* ========================
* = svcinit_release_info =
* ========================
*
* Overview:
*  This function initilizes the release information structure.
*  Initilization simply involves setting all the present flags to 
*  "not present".
*
* Arguments:
*
*  p_svc_release_info - Pointer to the release information.
*
* Returns:
*
* None
*
--*/

void svcinit_release_info (RELEASE_INFO *p_svc_release_info);

/*++
* ========================
* = svcinit_add_pty_info =
* ========================
*
* Overview:
*  This function initilizes the add party information structure.
*  Initilization simply involves setting all the present flags to 
*  "not present".
*
* Arguments:
*
*  p_svc_add_pty_info - Pointer to the add party information.
*
* Returns:
*
* None
*
--*/

void svcinit_add_pty_info (ADD_PTY_INFO *p_svc_add_pty_info);

/*++
* ==========================
* = svcinit_add_pty_status =
* ==========================
*
* Overview:
*  This function initilizes the add party status structure.
*  Initilization simply involves setting all the present flags to 
*  "not present".
*
* Arguments:
*
*  p_svc_add_pty_status - Pointer to the connection information.
*
* Returns:
*
* None
*
--*/

void svcinit_add_pty_status (ADD_PTY_STATUS *p_svc_add_pty_status);

/*++
* =========================
* = svcinit_drop_pty_info =
* =========================
*
* Overview:
*  This function initilizes the drop party information structure.
*  Initilization simply involves setting all the present flags to 
*  "not present".
*
* Arguments:
*
*  p_svc_drop_pty_info - Pointer to the drop party information.
*
* Returns:
*
* None
*
--*/

void svcinit_drop_pty_info (DROP_PTY_INFO *p_svc_drop_pty_info);

/*++
* =======================================
* = conn_info_called_party_address_copy =
* =======================================
*
* Overview:
*  Copy the called party address from the conn_info block into the
*  p_called_addr structure.
*
* Arguments:
*
*  p_called_addr - Pointer to the called address.
*  p_conn_info   - Pointer to the connection information structure.
*
* Returns:
*
*  STATUS_K_SUCCESS   - Successful copy.
*  STATUS_K_NOT_FOUND - The address is not present.
*
--*/

STATUS conn_info_called_party_address_copy (CONN_INFO *p_conn_info,
                                            ADDR_ATM  *p_called_addr);

/*++
* ========================================
* = conn_info_calling_party_address_copy =
* ========================================
*
* Overview:
*  Copy the calling party address from the conn_info block into the
*  p_called_addr structure.
*
* Arguments:
*
*  p_conn_info    - Pointer to the connection information structure.
*  p_calling_addr - Pointer to the calling address.
*
* Returns:
*
*  STATUS_K_SUCCESS   - Successful copy.
*  STATUS_K_NOT_FOUND - The address is not present.
*
--*/

STATUS conn_info_calling_party_address_copy (CONN_INFO *p_conn_info,
                                             ADDR_ATM  *p_calling_addr);

/*++
* ======================
* = conn_info_qos_copy =
* ======================
*
* Overview:
* Copy the QOS info from the conn_info block into the QOS structure. Note
* that the QOS structure is not related to any Trillium structure.
*
* Arguments:
*
*  p_conn_info - Pointer to the connection information structure.
*  p_qos       - Pointer to the quality of service "QOS" structure.
*
* Returns:
*
*  STATUS_K_SUCCESS   - Successful copy.
*  STATUS_K_NOT_FOUND - The QOS is not present.
*
--*/

STATUS conn_info_qos_copy (CONN_INFO  *p_conn_info,
                           QOS        *p_qos);

/*++
* ========================
* = svc_conn_info_id_get =
* ========================
*
* Overview:
*  Extract the VPI and VCI from the conn_info "connection information" block.
*
* Arguments:
*
*  p_conn_info - Pointer to the connection information structure.
*  p_vpi       - Pointer to virtual path indicator.
*  p_vci       - Pointer to virtual circuit indicator.
*
* Returns:
*
*  STATUS_K_SUCCESS   - Successful copy.
*  STATUS_K_NOT_FOUND - The connection ID is not present.
*
--*/

STATUS svc_conn_info_id_get (CONN_INFO *p_conn_info,
                             UINT8     *p_vpi,
                             UINT16    *p_vci);

/*++
* ==========================
* = svc_conn_status_id_get =
* ==========================
*
* Overview:
*  Extract the VPI and VCI from the conn_status block.
*
* Arguments:
*
*  p_conn_status - Pointer to the connection information structure.
*  p_vpi         - Pointer to virtual path indicator.
*  p_vci         - Pointer to virtual circuit indicator.
*
* Returns:
*
*  STATUS_K_SUCCESS   - Successful copy.
*  STATUS_K_NOT_FOUND - The connection ID is not present.
*
--*/

STATUS svc_conn_status_id_get (CONN_STATUS *p_conn_status,
                               UINT8       *p_vpi,
                               UINT16      *p_vci);

/*++
* ==================================
* = svc_conn_info_conn_sts_convert =
* ==================================
*
* Overview:
*  This function takes the information contained in a CONN_INFO structure
*  and copies it to a CONN_STATUS structure.
*
* Arguments:
*
*  p_conn_status - Pointer to the connection information structure.
*  p_vpi         - Pointer to virtual path indicator.
*  p_vci         - Pointer to virtual circuit indicator.
*
* Returns:
*
*  None.
*
--*/

void svc_conn_info_conn_sts_convert (CONN_INFO   *p_conn_info,
                                     CONN_STATUS *p_conn_status);

/*++
* ==========================
* = svc_release_info_make =
* ==========================
*
* Overview:
*  This function generates a RELEASE_INFO block appropriate to the indicated
*  error condition.
*
* Arguments:
*
*  code           - Error Code.
*  p_release_info - Pointer to the release information structure.
*
* Returns:
*
*  None
*
--*/

void svc_release_info_make (int           code,
                            RELEASE_INFO *p_release_info);
